CameraCapture class

The result for a camera capture session producing photos, videos, or both.

Constructors

CameraCapture({required List<Capture> captures})
Creates a new instance of CameraCapture.
const
CameraCapture.fromJson(Map<String, dynamic> json)
Creates a new instance from a JSON map.
factory

Properties

captures → List<Capture>
The individual captures from the session.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this instance to a JSON map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited