CameraReaction class

The result for a reaction camera recording session.

Constructors

CameraReaction({required Recording video, required List<Recording> recordings})
Creates a new instance of CameraReaction.
const
CameraReaction.fromJson(Map<String, dynamic> json)
Creates a new instance from a JSON map.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
recordings → List<Recording>
The recorded videos.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
video → Recording
The video that was reacted to (iOS only).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this instance to a JSON map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited