CameraResult class

The result of a camera session.

Constructors

CameraResult({CameraReaction? reaction, CameraCapture? capture, required Map<String, dynamic> metadata})
Creates a new instance of CameraResult.
const
CameraResult.fromJson(Map<String, dynamic> json)
Creates a new instance from a JSON map.
factory

Properties

capture → CameraCapture?
The capture result for a photo, video, or mixed camera session.
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → Map<String, dynamic>
The associated metadata.
final
reaction → CameraReaction?
The reaction result for a reaction camera session.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this instance to a JSON map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited