Capture class

A single capture from the camera. Either a still Photo or a video Recording.

Constructors

Capture({Photo? photo, Recording? video})
Creates a new instance of Capture.
const
Capture.fromJson(Map<String, dynamic> json)
Creates a new instance from a JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
photo Photo?
The captured still photo, when this is a photo capture.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
video Recording?
The video recording, when this is a video capture.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this instance to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited