CaptureCount enum
How many captures the camera session produces.
Values
- single → const CaptureCount
-
Produces a single capture and dismisses.
- multi → const CaptureCount
-
Stacks multiple captures into the progress ring.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String - Converts this instance to a JSON-serializable value.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
String value) → CaptureCount - Creates a new instance from a JSON value.
Constants
-
values
→ const List<
CaptureCount> - A constant List of the values in this enum, in order of their declaration.