CaptureType enum

The kind of media the camera captures.

Inheritance
Available extensions

Values

photo → const CaptureType

Captures still photos only.

video → const CaptureType

Records videos only.

mixed → const CaptureType

Switches between photo and video via an in-camera toggle.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
Converts this instance to a JSON-serializable value.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(String value) CaptureType
Creates a new instance from a JSON value.

Constants

values → const List<CaptureType>
A constant List of the values in this enum, in order of their declaration.