Photo class

A captured still photo. Contains one image in standard mode or two stacked images in dual camera mode.

Constructors

Photo({required List<PhotoImage> images, required double duration})
Creates a new instance of Photo.
const
Photo.fromJson(Map<String, dynamic> json)
Creates a new instance from a JSON map.
factory

Properties

duration double
The duration stamped on the photo, in milliseconds. Note: the React Native bridge passes this value in seconds instead.
final
hashCode int
The hash code for this object.
no setterinherited
images List<PhotoImage>
The individual image(s) of the photo capture.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this instance to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited