duration property
The duration stamped on the photo, in milliseconds. Note: the React Native bridge passes this value in seconds instead.
Implementation
final double duration;
The duration stamped on the photo, in milliseconds. Note: the React Native bridge passes this value in seconds instead.
final double duration;