PhotoImage class

A single image inside a photo capture.

Constructors

PhotoImage({required String uri, required Rect rect})
Creates a new instance of PhotoImage.
const
PhotoImage.fromJson(Map<String, dynamic> json)
Creates a new instance from a JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
rect Rect
The position and size of the image inside the dual-camera layout.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri String
A url to the photo file that is stored in a temporary location.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this instance to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited