Rect class

A rect used to determine video dimensions on the canvas.

Constructors

Rect({required double x, required double y, required double width, required double height})
Creates a new instance of Rect.
const
Rect.fromJson(Map<String, dynamic> json)
Creates a new instance from a JSON map.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → double
The height.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
The width.
final
x → double
The x coordinate of the top-left corner.
final
y → double
The y coordinate of the top-left corner.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this instance to a JSON map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited